- Workplace in sidebar now we should have sub menus
  > 1. Ideation
  > 2. UIUX Feedbacks
- Click workplace no longer redirect anywhere


For Ideation:
1. when we click on it redirect to existing workplace, and workplace page change the name to ideation.
2. for copilot on ideation file preview, it the button no longer clickable, and in it's hover config, let's add an option called refine idea, when click it, it does the original behavior
3. Make sure all the functions in workplace working properly after it.

For UIUX Feedbacks
1. create new page called UIUX Feedback
2. put working on progress working, I will have another feature to work on it.